@@ -35,7 +35,7 @@ class Dwoo
 	 *
 	 * @var string
 	 */
-	const VERSION = '1.1.0';
+	const VERSION = '1.1.1';
 
 	/**
 	 * unique number of this dwoo release
@@ -44,7 +44,7 @@ class Dwoo
 	 * has been compiled before this release or not, so that old templates are
 	 * recompiled automatically when Dwoo is updated
 	 */
-	const RELEASE_TAG = 16;
+	const RELEASE_TAG = 17;
 
 	/**#@+
 	 * constants that represents all plugin types
@@ -355,18 +355,19 @@ class Dwoo
 			}
 		} else {
 			// no cache present
-
 			if ($doCache === true) {
 				$dynamicId = uniqid();
 			}
 
 			// render template
-			$out = include $_tpl->getCompiledTemplate($this, $_compiler);
+			$compiledTemplate = $_tpl->getCompiledTemplate($this, $_compiler);
+			$out = include $compiledTemplate;
 
 			// template returned false so it needs to be recompiled
 			if ($out === false) {
 				$_tpl->forceCompilation();
-				$out = include $_tpl->getCompiledTemplate($this, $_compiler);
+				$compiledTemplate = $_tpl->getCompiledTemplate($this, $_compiler);
+				$out = include $compiledTemplate;
 			}
 
 			if ($doCache === true) {
@@ -374,7 +375,7 @@ class Dwoo
 				if (!class_exists('Dwoo_plugin_dynamic', false)) {
 					$this->getLoader()->loadPlugin('dynamic');
 				}
-				$out = Dwoo_Plugin_dynamic::unescape($out, $dynamicId);
+				$out = Dwoo_Plugin_dynamic::unescape($out, $dynamicId, $compiledTemplate);
 			}
 
 			// process filters
@@ -409,9 +410,8 @@ class Dwoo
 				// output
 				if ($_output === true) {
 					echo $out;
-				} else {
-					return $out;
 				}
+				return $out;
 			}
 		}
 	}
@@ -1059,10 +1059,11 @@ class Dwoo
 	 * this is so a single instance of every class plugin is created at each template run,
 	 * allowing class plugins to have "per-template-run" static variables
 	 *
+	 * @private
 	 * @param string $class the class name
 	 * @return mixed an object of the given class
 	 */
-	protected function getObjectPlugin($class)
+	public function getObjectPlugin($class)
 	{
 		if (isset($this->runtimePlugins[$class])) {
 			return $this->runtimePlugins[$class];
@@ -1523,6 +1524,10 @@ class Dwoo
 	 * @return mixed
 	 */
 	public function __call($method, $args) {
-		return call_user_func_array($this->getPluginProxy()->getCallback($method), $args);
+		$proxy = $this->getPluginProxy();
+		if (!$proxy) {
+			throw new Dwoo_Exception('Call to undefined method '.__CLASS__.'::'.$method.'()');
+		}
+		return call_user_func_array($proxy->getCallback($method), $args);
 	}
 }
